
/* -------------------------------------------------------------------------- */

/*

pgplot2.c

United States Naval Observatory
USNO/NRL Optical Interferometer
3450 Massachusetts Avenue, NW
Washington, DC  20392-5420

Subsystem:
----------
ptcl

Description:
------------
This file contains improved versions of PGPLOT functions.

Note:  This file externs data from the pgplotpackage_tclwrap.c file.  If you 
want to use this file without pgplotpackage_tclwrap.c, eliminate the extern and
set the global variable to the desired value.

Functions:
----------
pgerrx2, pgerry2.

Modification history:
---------------------
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Function created with functions pgerrx2( ) and pgerry2( ).

*/

/* -------------------------------------------------------------------------- */

/* Include files */

#include <stdio.h>   /* Standard I/O */
#include <stdlib.h>  /* Standard library */
#include <math.h>    /* Math */
#include <string.h>  /* String */

#include "memory.h"  /* Memory allocation/deallocation macros */
#include "message.h" /* Message function prototypes */

#include "ptcl.h"    /* ptcl */
#include "pgplot2.h" /* PGPLOT additional function prototypes */

/* -------------------------------------------------------------------------- */

/* Declare the external global variables */

extern int iNumDataPGPLOT;  /* This is the int variable which contains the
                               maximum number of data allowed for PGPLOT 
                               functions */

/* -------------------------------------------------------------------------- */

/* 

pgerrx2

Description:
------------
This function is a more versatile version of the PGPLOT function pgerrx( ) (the
function which plots x error bars).  For example, it takes the error bar sizes 
as an input, not the error bar limits.  Also, error bar multiples are allowed.

Inputs:
-------
*pliNumData - This is the pointer to the integer variable which contains the 
              number of data.
*prMultErr  - This is the pointer to the real variable which contains the error
              bar multiplier.
*prXErr     - This is the pointer to the 1D real array which contains the x 
              error bars.
*prX        - This is the pointer to the 1D real array which contains the x 
              values.
*prY        - This is the pointer to the 1D real array which contains the y 
              values.
*prSerif    - This is the pointer to the real variable which contains the serif
              length multiplier.

Outputs:
--------
None.

Modification history:
---------------------
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

void pgerrx2( integer *pliNumData, real *prMultErr, real *prXErr, real *prX,
    real *prY, real *prSerif ) 

{

  /* Declare the local variables */
  
  int iData;     /* This is the int variable which contains the data counter */
  
  real *prXHigh; /* This is the pointer to the 1D real array which contains the
                    high x values */
  real *prXLow;  /* This is the pointer to the 1D real array which contains the
                    low x values */
  
  
  /* Check the input parameters */
  
  if ( *pliNumData < 1 || *pliNumData > iNumDataPGPLOT )
  {
    NrWarning( "!! pgerrx2:  Number of data invalid..." );
    return;
  }
  
  if ( *prMultErr <= 0.0 )
  {
    NrWarning( "!! pgerrx2:  Error bar multiplier must be > 0.0 ..." );
    return;
  }
  
  if ( *prSerif <= 0.0 )
  {
    NrWarning( "!! pgerrx2:  Serif length multiplier must be > 0.0 ..." );
    return;
  }
  
  
  /* Allocate the memory */
  
  ALLOC1( prXHigh, real, ( *pliNumData - 1 ) );
  ALLOC1( prXLow, real, ( *pliNumData - 1 ) );
  
  
  /* Calculate the error bar limits and plot them */

  for ( iData = 0; iData <= ( *pliNumData - 1 ); iData++ )
  {
    prXLow[iData] = prX[iData] - ( *prMultErr * prXErr[iData] );
    prXHigh[iData] = prX[iData] + ( *prMultErr * prXErr[iData] );
  }

#if COMPILE == 0
  pgerrx( pliNumData, prXLow, prXHigh, prY, prSerif );
#elif COMPILE == 1
  pgerrx_( pliNumData, prXLow, prXHigh, prY, prSerif );
#elif COMPILE == 2
  cpgerrx( *pliNumData, prXLow, prXHigh, prY, *prSerif );
#else
  cpgerrx( *pliNumData, prXLow, prXHigh, prY, *prSerif );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prXHigh );
  DEALLOC1( prXLow );
  
  
  /* Return to the calling function */
  
  return;
  
}

/* -------------------------------------------------------------------------- */

/* 

pgerry2

Description:
------------
This function is a more versatile version of the PGPLOT function pgerry( ) (the
function which plots y error bars).  For example, it takes the error bar sizes 
as an input, not the error bar limits.  Also, error bar multiples are allowed.

Inputs:
-------
*pliNumData - This is the pointer to the integer variable which contains the 
              number of data.
*prMultErr  - This is the pointer to the real variable which contains the error
              bar multiplier.
*prYErr     - This is the pointer to the 1D real array which contains the y
              error bars.
*prX        - This is the pointer to the 1D real array which contains the x 
              values.
*prY        - This is the pointer to the 1D real array which contains the y 
              values.
*prSerif    - This is the pointer to the real variable which contains the serif
              length multiplier.

Outputs:
--------
None.

Modification history:
---------------------
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

void pgerry2( integer *pliNumData, real *prMultErr, real *prYErr, real *prX,
    real *prY, real *prSerif ) 

{

  /* Declare the local variables */
  
  int iData;     /* This is the int variable which contains the data counter */
  
  real *prYHigh; /* This is the pointer to the 1D real array which contains the
                    high y values */
  real *prYLow;  /* This is the pointer to the 1D real array which contains the
                    low y values */
  
  
  /* Check the input parameters */
  
  if ( *pliNumData < 1 || *pliNumData > iNumDataPGPLOT )
  {
    NrWarning( "!! pgerry2:  Number of data invalid..." );
    return;
  }
  
  if ( *prMultErr <= 0.0 )
  {
    NrWarning( "!! pgerry2:  Error bar multiplier must be > 0.0 ..." );
    return;
  }
  
  if ( *prSerif <= 0.0 )
  {
    NrWarning( "!! pgerry2:  Serif length multiplier must be > 0.0 ..." );
    return;
  }
  
  
  /* Allocate the memory */
  
  ALLOC1( prYHigh, real, ( *pliNumData - 1 ) );
  ALLOC1( prYLow, real, ( *pliNumData - 1 ) );
  
  
  /* Calculate the error bar limits and plot them */

  for ( iData = 0; iData <= ( *pliNumData - 1 ); iData++ )
  {
    prYLow[iData] = prY[iData] - ( *prMultErr * prYErr[iData] );
    prYHigh[iData] = prY[iData] + ( *prMultErr * prYErr[iData] );
  }

#if COMPILE == 0
  pgerry( pliNumData, prX, prYHigh, prYLow, prSerif );
#elif COMPILE == 1
  pgerry_( pliNumData, prX, prYHigh, prYLow, prSerif );
#elif COMPILE == 2
  cpgerry( *pliNumData, prX, prYHigh, prYLow, *prSerif );
#else
  cpgerry( *pliNumData, prX, prYHigh, prYLow, *prSerif );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prYHigh );
  DEALLOC1( prYLow );
  
  
  /* Return to the calling function */
  
  return;
  
}

